Solo2

Struct Solo2 

pub struct Solo2 { /* private fields */ }
A SoloKeys Solo 2 device, in regular mode.

From an inventory perspective, the core identifier is a UUID (16 bytes / 128 bits).

From an interface perspective, either the CTAP or PCSC transport must be available. Therefore, it is an invariant that at least one is interface, and the device itself implements Transport.

Implementations

Source

impl Solo2

pub fn transport_preference() -> TransportPreference

pub fn prefer_ctap()

pub fn prefer_pcsc()

pub fn into_lpc55(self) -> Result<Lpc55>

NB: Requires user tap

Source

impl Solo2

pub fn uuid(&self) -> Uuid

UUID of device.

pub fn version(&self) -> Version

Firmware version on device.

pub fn as_ctap(&self) -> Option<&Device>

pub fn as_ctap_mut(&mut self) -> Option<&mut Device>

pub fn as_pcsc(&self) -> Option<&Device>

pub fn as_pcsc_mut(&mut self) -> Option<&mut Device>