pub struct Solo2 { /* private fields */ }Expand description
A SoloKeys Solo 2 device, in regular mode.
From an inventory perspective, the core identifier is a UUID (16 bytes / 128 bits).
From an interface perspective, either the CTAP or PCSC transport must be available. Therefore, it is an invariant that at least one is interface, and the device itself implements Transport.
Implementations
Sourceimpl Solo2
impl Solo2
pub fn transport_preference() -> TransportPreference
pub fn prefer_ctap()
pub fn prefer_pcsc()
Sourcepub fn into_lpc55(self) -> Result<Lpc55>
pub fn into_lpc55(self) -> Result<Lpc55>
NB: Requires user tap